@@ -30,7 +30,7 @@ class ReadExcel():
                 # print(listApiData)
             return listApiData
         else:
-            print("表格是空数据!")
+            #print("表格是空数据!")
             return None
 
 
