@@ -43,4 +43,5 @@ class SendRequests():
             re = s.request(method=method, url=url, headers=h, params=par, data=body, verify=v)
             return re
         except Exception as e:
-            print(e)
+            pass
+            #print(e)
